/*
 * This file is part of brisk-menu.
 *
 * Copyright © 2016-2019 Brisk Menu Developers
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 */

/**
 * Style for the main window itself
 */
#define BRISK_STYLE_MAIN "brisk-menu"

/**
 * Right hand side application list
 */
#define BRISK_STYLE_APPS_LIST "apps-list"

/**
 * Left hand side category list
 */
#define BRISK_STYLE_SIDEBAR "categories-list"

/**
 * Main toggle button
 */
#define BRISK_STYLE_BUTTON "brisk-button"

/**
 * We're in a vertical layout
 */
#define BRISK_STYLE_BUTTON_VERTICAL "brisk-button-vertical"

/**
 * This is a dash window
 */
#define BRISK_STYLE_DASH "brisk-dash"

/*
 * Editor modelines  -  https://www.wireshark.org/tools/modelines.html
 *
 * Local variables:
 * c-basic-offset: 8
 * tab-width: 8
 * indent-tabs-mode: nil
 * End:
 *
 * vi: set shiftwidth=8 tabstop=8 expandtab:
 * :indentSize=8:tabSize=8:noTabs=true:
 */
